"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const convertScopedCssForEmotion_1 = require("./convertScopedCssForEmotion");
const convertScopeToModuleName_1 = require("./convertScopeToModuleName");
const getCssIndexedByScope_1 = require("./getCssIndexedByScope");
const getRequiredScopes_1 = require("./getRequiredScopes");
function convertCssForEmotion(css) {
    const cssIndexedByScope = getCssIndexedByScope_1.getCssIndexedByScope(css);
    const collator = new Intl.Collator(undefined, {
        numeric: true,
        sensitivity: "base",
    });
    const knownScopes = new Set([...cssIndexedByScope.keys()]);
    const sortedKnownScopes = [...knownScopes]
        .sort((scopeA, scopeB) => {
        if (scopeA === "root") {
            return -1;
        }
        if (scopeA[0] === "." && scopeB[0] !== ".") {
            return +1;
        }
        if (scopeA[0] !== "." && scopeB[0] === ".") {
            return -1;
        }
        return collator.compare(scopeA, scopeB);
    })
        .reduce((previousSortedKnownScopes, knownScope) => {
        getRequiredScopes_1.getRequiredScopes(cssIndexedByScope.get(knownScope), knownScope, knownScopes).forEach((requiredScope) => {
            if (previousSortedKnownScopes.has(requiredScope) === false) {
                previousSortedKnownScopes.add(requiredScope);
            }
        });
        if (previousSortedKnownScopes.has(knownScope) === false) {
            previousSortedKnownScopes.add(knownScope);
        }
        return previousSortedKnownScopes;
    }, new Set());
    let cssForEmotion = `import { ${[
        [...sortedKnownScopes].some((scope) => scope[0] === ".") ? "css" : "",
        sortedKnownScopes.has("root") ? "injectGlobal" : "",
        [...sortedKnownScopes].some((scope) => scope !== "root" && scope[0] !== ".")
            ? "styled"
            : "",
    ]
        .filter(String)
        .join(", ")} } from "emotion";\n`;
    sortedKnownScopes.forEach((scope) => {
        cssForEmotion += "\n";
        const convertedScopedCssForEmotion = convertScopedCssForEmotion_1.convertScopedCssForEmotion(cssIndexedByScope.get(scope), scope, knownScopes);
        if (scope === "root") {
            cssForEmotion += `injectGlobal\`${convertedScopedCssForEmotion}\`;\n`;
        }
        else {
            cssForEmotion += `export const ${convertScopeToModuleName_1.convertScopeToModuleName(scope)} = ${scope[0] === "."
                ? "css"
                : `styled.${scope}`}\`${convertedScopedCssForEmotion}\`;\n`;
        }
    });
    return cssForEmotion;
}
exports.convertCssForEmotion = convertCssForEmotion;
